@@ -1,11 +1,12 @@
 import os
 
 from parser.YAML_parser import YAMLParser
-from parser.feature_engineering_parser import FeatureEngineeringParser
-from parser.model_parser import ModelParser
+from interbase_code.parser.feature_engineering_parser import FeatureEngineeringParser
+from interbase_code.parser.model_parser import ModelParser
 
 if __name__ != "__main__":
-    exit()   
+    exit()
+
 
 def get_config():
     initialParser = YAMLParser
@@ -15,18 +16,20 @@ def get_config():
     for file in os.listdir('./yamls'):
         filepath = os.path.join('./yamls', file)
         config = initialParser(filepath).parse()
-    
-        features_configs, columns_set_alias = featureEngineringParser(filepath).parse(config['feature_engineering'])
+
+        features_configs, columns_set_alias = featureEngineringParser(
+            filepath).parse(config['feature_engineering'])
         del config['feature_engineering']
-        
+
         model_configs = modelParser(columns_set_alias).parse(config['model'])
         del config['model']
-        
+
         print("FEATURES")
         print(features_configs)
         print(3*'\n')
         print(20*'-')
         print(3*'\n')
         print(model_configs)
-         
+
+
 get_config()
